@@ -7,7 +7,14 @@ def color_imbalanced(raw_input):
     the css property `'color: red'` for negative
     strings, black otherwise.
     """
-    pattern = re.compile(r'(\d+)')
-    val = int(pattern.search(raw_input)[0])
-    color = constance_object.BLACK if val < 90 else constance_object.RED
+
+    color = constance_object.BLACK
+    if raw_input != "0.00":
+        pattern = re.compile(r'(: )(\d+)')
+        val = int(pattern.search(raw_input)[2])
+        if val > 90:
+            color =  constance_object.RED
     return constance_object.OUTPUT.format(color)
+
+
+
